@@ -51,8 +51,16 @@ module IAIConvert
       levels = collect(dtype.categories)
       ordered = dtype.ordered
 
-      vals = CategoricalArray(vals, ordered=ordered)
-      levels!(vals, levels)
+      try
+        vals = CategoricalArray(vals, ordered=ordered)
+        levels!(vals, levels)
+      catch
+        # Force convert vals to a Missing/String vector
+        vals = Union{Missing,String}[ismissing(v) ? v : string(v) for v in vals]
+        vals = CategoricalArray(vals, ordered=ordered)
+        levels!(vals, string.(levels))
+      end
+
     elseif dtype.name in keys(DTYPE_MAPPING)
       vtype = DTYPE_MAPPING[dtype.name]
       if !isempty(missing_inds)
@@ -197,3 +205,16 @@ end
     end
   end
 end
+
+# Add fallback definition for `get_machine_id` so we can use it on older IAI
+if !isdefined(IAI, :get_machine_id_convert)
+  if isdefined(IAI, :IAILicensing)
+    @eval IAI begin
+      get_machine_id_convert() = IAILicensing.machine_id()
+    end
+  else
+    @eval IAI begin
+      get_machine_id_convert() = IAIBase.machine_id()
+    end
+  end
+end
