@@ -84,6 +84,16 @@ def add_julia_processes(*args):
     return out
 
 
+def get_machine_id():
+    """Return the machine ID for the current computer.
+
+    Examples
+    --------
+    >>> iai.get_machine_id()
+    """
+    return _IAI.get_machine_id_convert()
+
+
 def _get_learner_type(jl_obj):
     if _Main.isa(jl_obj, _IAI.OptimalTreeClassifier):
         L = OptimalTreeClassifier
