@@ -217,7 +217,7 @@ class SupervisedLearner(Learner):
         """
         return _IAI.score_convert(self._jl_obj, *args, **kwargs)
 
-    def variable_importance(self):
+    def variable_importance(self, *args, **kwargs):
         """Generate a ranking of the variables in the learner according to
         their importance during training. The results are normalized so that
         they sum to one.
@@ -229,7 +229,7 @@ class SupervisedLearner(Learner):
         --------
         >>> lnr.variable_importance()
         """
-        return _IAI.variable_importance_convert(self._jl_obj)
+        return _IAI.variable_importance_convert(self._jl_obj, *args, **kwargs)
 
     def get_features_used(self):
         """Return a list of feature names used by the learner.
