@@ -499,6 +499,44 @@ class ClassificationTreeLearner(ClassificationLearner):
         return _IAI.get_classification_proba_convert(self._jl_obj, node_index,
                                                      **kwargs)
 
+    def get_regression_constant(self, node_index, **kwargs):
+        """Return the constant term in the logistic regression prediction at
+        node `node_index` in the trained learner.
+
+        Julia Equivalent:
+        `IAI.get_regression_constant <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.ClassificationTask%7D%2CInt64%7D>`
+
+        Examples
+        --------
+        >>> lnr.get_regression_constant(node_index)
+
+        Compatibility
+        -------------
+        Requires IAI version 3.0 or higher.
+        """
+        _requires_iai_version("3.0.0", "get_regression_constant")
+        return _IAI.get_regression_constant_convert(self._jl_obj, node_index,
+                                                    **kwargs)
+
+    def get_regression_weights(self, node_index, **kwargs):
+        """Return the weights for each feature in the logistic regression
+        prediction at node `node_index` in the trained learner.
+
+        Julia Equivalent:
+        `IAI.get_regression_weights <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.ClassificationTask%7D%2CInt64%7D>`
+
+        Examples
+        --------
+        >>> lnr.get_regression_weights(node_index)
+
+        Compatibility
+        -------------
+        Requires IAI version 3.0 or higher.
+        """
+        _requires_iai_version("3.0.0", "get_regression_constant")
+        return _IAI.get_regression_weights_convert(self._jl_obj, node_index,
+                                                   **kwargs)
+
     def set_threshold(self, *args, **kwargs):
         """For a binary classification problem, update the the predicted labels
         in the leaves of the learner to predict `label` only if the predicted
