@@ -1,3 +1,4 @@
+import julia
 import os
 import pathlib
 import re
@@ -89,16 +90,17 @@ def iai_run_julia_setup(**kwargs):
     os.environ['IAI_DISABLE_INIT'] = 'True'
 
     # Start julia once in case artifacts need to be downloaded
-    args = [kwargs.get('runtime', julia_exename())]
-    if 'sysimage' in kwargs:
-        args.extend(['-J', kwargs['sysimage']])
-    args.extend(['-e', 'nothing'])
-    subprocess.run(args, stdout=subprocess.DEVNULL)
+    # Skip if julia is already inited, as we may not know `runtime`
+    if not julia.libjulia.get_libjulia():
+        args = [kwargs.get('runtime', julia_exename())]
+        if 'sysimage' in kwargs:
+            args.extend(['-J', kwargs['sysimage']])
+        args.extend(['-e', 'nothing'])
+        subprocess.run(args, stdout=subprocess.DEVNULL)
 
     # Do custom Julia init if required
     if len(kwargs) > 0:
-        from julia import Julia
-        Julia(**kwargs)
+        julia.Julia(**kwargs)
 
     from julia import Main as _Main
 
