@@ -54,14 +54,20 @@ class Predictor():
                 }
 
         if self.model['_julia_type'] == 'OptimalFeatureSelectionClassifier':
-            fit = self.model['fit_']
+            if 'fit_' in self.model:
+                fit = self.model['fit_']
+            else:
+                fit = self.model['fits_'][0]
             if 'inner' in fit:
                 fit = fit['inner']
             else:
                 fit = fit['logistic_fit']
             fit['beta'] = convert_sparse_vector(fit['beta'])
         elif self.model['_julia_type'] == 'OptimalFeatureSelectionRegressor':
-            fit = self.model['fit_']
+            if 'fit_' in self.model:
+                fit = self.model['fit_']
+            else:
+                fit = self.model['fits_'][0]
             fit['beta'] = convert_sparse_vector(fit['beta'])
         else:
             # Convert "Infinity" to inf for thresholds
@@ -141,6 +147,7 @@ class Predictor():
         onehot_j = numeric_j - features['n_numeric_orig_features']
         if onehot_j >= 0:
             onehot_start = features['onehot_start_index'][j]
+            onehot_end = features['onehot_start_index'][j + 1]
             level_ind = numeric_j - onehot_start
             ordinal_feature_map = {
                 int(k): int(v)
@@ -148,16 +155,32 @@ class Predictor():
             }
             ordinal_j = ordinal_feature_map.get(j + 1, 0) - 1
 
+            cat_levels = features['categoric_labelmap'][j]['levels']
+            leq_range = range(0, 0)
+
             label_map = []
             if ordinal_j >= 0:
-                label_map.extend(
-                    features['ordinal_labelmap'][ordinal_j]['levels'])
+                ord_levels = features['ordinal_labelmap'][ordinal_j]['levels']
+                label_map.extend(ord_levels)
 
-            label_map.extend(features['categoric_labelmap'][j]['levels'])
+                # Check if we need to account for <= onehot
+                n_levels = len(cat_levels) - 1 + len(ord_levels)
+                if n_levels > 2 and (onehot_end - onehot_start) > n_levels:
+                    leq_levels = ord_levels[1:-2]
+                    leq_range = range(len(label_map),
+                                      len(label_map) + len(leq_levels))
+                    label_map.extend(leq_levels)
+
+            label_map.extend(cat_levels)
             # remove missing level
             label_map.remove('missing')
-            level = label_map[level_ind]
-            return (x[feature_name] == level) * coef
+            if level_ind in leq_range:
+                levels = level_ind - len(ord_levels) + 2
+                return (x[feature_name] in ord_levels[0:levels]) * coef
+            else:
+                level = label_map[level_ind]
+                return (x[feature_name] == level) * coef
+
         else:
             return x[feature_name] * coef
 
@@ -259,7 +282,10 @@ class Predictor():
             # convert to probability matrix
             target = model['prb_']['data']['target']
             target_levels = target['classes']['levels']
-            fit = model['fit_']
+            if 'fit_' in model:
+                fit = model['fit_']
+            else:
+                fit = model['fits_'][0]
             if 'inner' in fit:
                 fit = fit['inner']
             else:
@@ -432,7 +458,10 @@ class Predictor():
         model = self.model
         learner_type = model['_julia_type']
 
-        fit = model['fit_']
+        if 'fit_' in model:
+            fit = model['fit_']
+        else:
+            fit = model['fits_'][0]
         if learner_type == 'OptimalFeatureSelectionClassifier':
             if 'inner' in fit:
                 fit = fit['inner']
