@@ -562,7 +562,8 @@ class CategoricalRewardEstimator(CategoricalRewardEstimationLearner):
     This class was deprecated in interpretableai 2.6.0, and
     CategoricalClassificationRewardEstimator or
     CategoricalRegressionRewardEstimator should be used instead. This is for
-    consistency with the IAI v2.1.0 Julia release.
+    consistency with the IAI v2.1.0 Julia release. This deprecation is no
+    longer supported as of the IAI v3 release.
 
     Examples
     --------
@@ -575,10 +576,14 @@ class CategoricalRewardEstimator(CategoricalRewardEstimationLearner):
 
     Compatibility
     -------------
-    Requires IAI version 2.0 or higher.
+    Requires IAI version 2.0, 2.1 or 2.2.
     """
     def __init__(self, *args, propensity_estimator=None,
                  outcome_estimator=None, **kwargs):
+        if not _iai_version_less_than("2.3.0"):
+            raise RuntimeError(
+                "'CategoricalRewardEstimator' was removed in IAI v3")
+
         _requires_iai_version("2.0.0", "CategoricalRewardEstimator")
         _warnings.warn(
             "'CategoricalRewardEstimator' is deprecated, use " +
@@ -622,9 +627,16 @@ class RewardEstimator(CategoricalRewardEstimator, RewardEstimationLearner):
 
     This class was deprecated and renamed to CategoricalRewardEstimator in
     interpretableai 2.3.0. This is for consistency with the IAI v2.1.0 Julia
-    release.
+    release. This deprecation is no longer supported as of the IAI v3 release.
+
+    Compatibility
+    -------------
+    Requires IAI version 2.2 or lower.
     """
     def __init__(self, *args, **kwargs):
+        if not _iai_version_less_than("2.3.0"):
+            raise RuntimeError("'RewardEstimator' was removed in IAI v3")
+
         _warnings.warn(
             "'RewardEstimator' is deprecated, use " +
             "'CategoricalRewardEstimator'",
@@ -639,7 +651,8 @@ class NumericRewardEstimator(NumericRewardEstimationLearner):
     This class was deprecated in interpretableai 2.6.0, and
     RegressionClassificationRewardEstimator or
     RegressionRegressionRewardEstimator should be used instead. This is for
-    consistency with the IAI v2.1.0 Julia release.
+    consistency with the IAI v2.1.0 Julia release. This deprecation is no
+    longer supported as of the IAI v3 release.
 
     Examples
     --------
@@ -652,9 +665,13 @@ class NumericRewardEstimator(NumericRewardEstimationLearner):
 
     Compatibility
     -------------
-    Requires IAI version 2.1 or higher.
+    Requires IAI version 2.1 or 2.2.
     """
     def __init__(self, *args, outcome_estimator=None, **kwargs):
+        if not _iai_version_less_than("2.3.0"):
+            raise RuntimeError(
+                "'NumericRewardEstimator' was removed in IAI v3")
+
         _requires_iai_version("2.1.0", "NumericRewardEstimator")
         _warnings.warn(
             "'NumericRewardEstimator' is deprecated, use " +
